# Identical bid prices (R028)

Different tenderers submitted bids with the same price.

## Methodology

A contracting process is flagged if different tenderers submitted bids with the same price.

These tenderers are also flagged.

:::{admonition} Example
:class: seealso

The Ministry of Defense opens bids early and leaks the lowest price to BribeCorp. BribeCorp submits a bid matching the lowest price. The Ministry of Defense awards the contract to BribeCorp.
:::

:::{admonition} Why is this a red flag?
:class: hint

A corrupt buyer can award the pre-determined bidder by leaking competitors' prices.
:::

<small>Based on "Bidders having the same bid price" in [*Assessing the potential for detecting collusion in Swedish public procurement*](https://www.govtransparency.eu/wp-content/uploads/2021/08/Fazekas-Toth_SE_PPcartel_detection_20161115.pdf) and "Different companies include identical unit prices in their bid documents" in [*Fraud in Public Procurement: A collection of Red Flags and Best Practices*](https://ec.europa.eu/sfc/system/files/documents/sfc-files/fraud-public-procurement-final-20122017-ares20176254403.pdf).</small>

## Output

The indicator's value is always 1.0.

If the ``--map`` command-line flag is set, the ``Maps`` key contains:

ocid_tenderer_r028
: The flagged tenderers for each flagged `ocid`.

## Configuration

The indicator is not configurable.

:::{seealso}
`no_price_comparison_procurement_methods` and `price_comparison_procurement_methods` in {ref}`global-configuration`
:::

## Exclusions

A contracting process is excluded if:

- Prices are predetermined by the buyer.

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/028.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/settings.ini --no-meta docs/examples/R/028.jsonl
{"OCID":{"F":{"R028":1.0}},"Tenderer":{"D":{"R028":1.0},"V":{"R028":1.0}}}

```
